AuthData class

Constructors

AuthData(Map<String, dynamic>? channelData, String? sharedSecret)
const
AuthData.fromJson(Map<String, dynamic> json)
factory

Properties

channelData Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedSecret String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited