ListStorageModelExtension extension

on

Properties

ids List<String>

Available on List<StorageModel>, provided by the ListStorageModelExtension extension

Gets a list of IDs from the models in the list.
no setter
refs List<String>

Available on List<StorageModel>, provided by the ListStorageModelExtension extension

Gets a list of references from the models in the list.
no setter

Methods

getMap() List<Map>

Available on List<StorageModel>, provided by the ListStorageModelExtension extension

Converts the list of models to a list of maps.
save() Future

Available on List<StorageModel>, provided by the ListStorageModelExtension extension

Saves all models in the list to the database.