MapStorageModelExtension extension

on

Properties

ids List<String>

Available on Map<String, StorageModel>, provided by the MapStorageModelExtension extension

Gets a list of IDs from the models in the list.
no setter
refs List<String>

Available on Map<String, StorageModel>, provided by the MapStorageModelExtension extension

Gets a list of references from the models in the list.
no setter

Methods

getMap() Map<String, Map>

Available on Map<String, StorageModel>, provided by the MapStorageModelExtension extension

Converts the map of models to a map of maps.
save() Future

Available on Map<String, StorageModel>, provided by the MapStorageModelExtension extension

Saves all models in the list to the database.