whisper method
Register a callback to be called anytime the member list changes.
Implementation
void whisper(String eventName, dynamic data) {
throw Exception('This method is not available for encrypted channels');
}
Register a callback to be called anytime the member list changes.
void whisper(String eventName, dynamic data) {
throw Exception('This method is not available for encrypted channels');
}