stopListening method
Stop listening for an event on the channel instance.
Implementation
@override
void stopListening(String event, [Function? callback]) =>
subscription.unbind(EventFormatter.format(event, options.nameSpace));
Stop listening for an event on the channel instance.
@override
void stopListening(String event, [Function? callback]) =>
subscription.unbind(EventFormatter.format(event, options.nameSpace));