ListStorageModelExtension extension
- on
Properties
-
ids
→ List<
String> -
Available on List<
Gets a list of IDs from the models in the list.StorageModel> , provided by the ListStorageModelExtension extensionno setter -
refs
→ List<
String> -
Available on List<
Gets a list of references from the models in the list.StorageModel> , provided by the ListStorageModelExtension extensionno setter
Methods
-
getMap(
) → List< Map> -
Available on List<
Converts the list of models to a list of maps.StorageModel> , provided by the ListStorageModelExtension extension -
save(
) → Future -
Available on List<
Saves all models in the list to the database.StorageModel> , provided by the ListStorageModelExtension extension