MapStorageModelExtension extension
- on
Properties
-
ids
→ List<
String> -
Available on Map<
Gets a list of IDs from the models in the list.String, StorageModel> , provided by the MapStorageModelExtension extensionno setter -
refs
→ List<
String> -
Available on Map<
Gets a list of references from the models in the list.String, StorageModel> , provided by the MapStorageModelExtension extensionno setter
Methods
-
getMap(
) → Map< String, Map> -
Available on Map<
Converts the map of models to a map of maps.String, StorageModel> , provided by the MapStorageModelExtension extension -
save(
) → Future -
Available on Map<
Saves all models in the list to the database.String, StorageModel> , provided by the MapStorageModelExtension extension