StorageModelRegister class
Constructors
- StorageModelRegister({required StorageModel encoder(dynamic data), String? collectionId})
-
const
Properties
- collectionId → String?
-
final
- encoder → StorageModel Function(dynamic data)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
encode<
MT extends StorageModel> (dynamic data) → MT -
get<
MT extends StorageModel> () → StorageModelRegister? -
getCollectionId<
MT extends StorageModel> ([Type? type]) → String? -
register<
MT extends StorageModel> (StorageModel encoder(dynamic data), [String? collectionId, Type? type]) → void -
registerAll(
Map< Type, StorageModelRegister> models) → void